@@ -4,10 +4,15 @@ use warnings;
 use base qw(App::Hachero::Plugin::Base);
 use Regexp::Log::Common;
 
-sub init {
+sub initialize : Hook {
     my ($self, $context) = @_;
+    my $config = $self->config->{config};
+    for (keys %{$config->{REGEXP}}) {
+        $Regexp::Log::Common::REGEXP{$_} = $config->{REGEXP}->{$_};
+    }
     my $regexp = Regexp::Log::Common->new(
-        format => $self->config->{config}->{format} || ':extended',
+        format => $config->{format} || ':extended',
+        ($config->{capture} ? (capture => $config->{capture}) : ()),
     );
     $self->{re} = $regexp->regexp;
     @{$self->{capture}} = $regexp->capture;
@@ -25,8 +30,6 @@ __END__
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 App::Hachero::Plugin::Parse::Common - parses common apache logs
